@@ -42,6 +42,16 @@ int clientmax = ACPID_CLIENTMAX;
 /* the number of non-root clients that are connected */
 int non_root_clients;
 
+/* determine if a file descriptor is in fact a socket */
+int
+is_socket(int fd)
+{
+	int v;
+	socklen_t l = sizeof(int);
+
+	return (getsockopt(fd, SOL_SOCKET, SO_TYPE, (char *)&v, &l) == 0);
+}
+
 /* accept a new client connection */
 static void
 process_sock(int fd)
@@ -103,56 +113,62 @@ open_sock()
 	int fd;
 	struct connection c;
 
-	fd = ud_create_socket(socketfile);
-	if (fd < 0) {
-		acpid_log(LOG_ERR, "can't open socket %s: %s",
-			socketfile, strerror(errno));
-		exit(EXIT_FAILURE);
+	/* if this is a socket passed in via stdin by systemd */
+	if (is_socket(STDIN_FILENO)) {
+		fd = STDIN_FILENO;
+	} else {
+		/* create our own socket */
+		fd = ud_create_socket(socketfile);
+		if (fd < 0) {
+			acpid_log(LOG_ERR, "can't open socket %s: %s",
+				socketfile, strerror(errno));
+			exit(EXIT_FAILURE);
+		}
+
+		if (chmod(socketfile, socketmode) < 0) {
+			close(fd);
+			acpid_log(LOG_ERR, "chmod() on socket %s: %s", 
+		        socketfile, strerror(errno));
+			return;
+		}
+
+		/* if we need to change the socket's group, do so */
+		if (socketgroup) {
+			struct group *gr;
+			struct stat buf;
+
+		    gr = getgrnam(socketgroup);
+			if (!gr) {
+				acpid_log(LOG_ERR, "group %s does not exist", socketgroup);
+				exit(EXIT_FAILURE);
+			}
+			if (stat(socketfile, &buf) < 0) {
+				acpid_log(LOG_ERR, "can't stat %s: %s", 
+		            socketfile, strerror(errno));
+				exit(EXIT_FAILURE);
+			}
+			if (chown(socketfile, buf.st_uid, gr->gr_gid) < 0) {
+				acpid_log(LOG_ERR, "can't chown %s: %s", 
+		            socketfile, strerror(errno));
+				exit(EXIT_FAILURE);
+			}
+		}
 	}
 
-    /* don't leak fds when execing */
-    if (fcntl(fd, F_SETFD, FD_CLOEXEC) < 0) {
+	/* don't leak fds when execing */
+	if (fcntl(fd, F_SETFD, FD_CLOEXEC) < 0) {
 		close(fd);
 		acpid_log(LOG_ERR, "fcntl() on socket %s for FD_CLOEXEC: %s", 
-            socketfile, strerror(errno));
+		          socketfile, strerror(errno));
 		return;
-    }
+	}
 
-    /* avoid a potential hang */
-    if (fcntl(fd, F_SETFL, O_NONBLOCK) < 0) {
+	/* avoid a potential hang */
+	if (fcntl(fd, F_SETFL, O_NONBLOCK) < 0) {
 		close(fd);
 		acpid_log(LOG_ERR, "fcntl() on socket %s for O_NONBLOCK: %s", 
-            socketfile, strerror(errno));
+		          socketfile, strerror(errno));
 		return;
-    }
-
-	if (chmod(socketfile, socketmode) < 0) {
-		close(fd);
-		acpid_log(LOG_ERR, "chmod() on socket %s: %s", 
-            socketfile, strerror(errno));
-		return;
-    }
-
-    /* if we need to change the socket's group, do so */
-	if (socketgroup) {
-		struct group *gr;
-		struct stat buf;
-
-        gr = getgrnam(socketgroup);
-		if (!gr) {
-			acpid_log(LOG_ERR, "group %s does not exist", socketgroup);
-			exit(EXIT_FAILURE);
-		}
-		if (stat(socketfile, &buf) < 0) {
-			acpid_log(LOG_ERR, "can't stat %s: %s", 
-                socketfile, strerror(errno));
-			exit(EXIT_FAILURE);
-		}
-		if (chown(socketfile, buf.st_uid, gr->gr_gid) < 0) {
-			acpid_log(LOG_ERR, "can't chown %s: %s", 
-                socketfile, strerror(errno));
-			exit(EXIT_FAILURE);
-		}
 	}
 	
 	/* add a connection to the list */
